@@ -84,11 +84,11 @@ def get_object(bucket_name: str, path: str) -> bytes:
     return body
 
 
-def list_objects(bucket_name: str, path: str, recursive: bool = True) -> Generator[Object, None, None]:
-    path = get_absolute_path(path)
+def list_objects(bucket_name: str, prefix: str, recursive: bool = True) -> Generator[Object, None, None]:
+    prefix = get_absolute_path(prefix)
     s3_client = get_s3_client()
 
-    yield from s3_client.list_objects(bucket_name, path, recursive)
+    yield from s3_client.list_objects(bucket_name, prefix=prefix, recursive=recursive)
 
 
 def get_objects(bucket_name: str, path: str, recursive: bool = True) -> Generator[tuple[str, bytes], None, None]:
